@@ -170,8 +170,8 @@ class EvalMetric:
                     targets.append(target)
                     data_score.append([predict, target, {'wer': wer, 'cer': cer}])
 
-                wer = 100 * asrp.chunked_wer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
-                cer = 100 * asrp.chunked_cer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
+                wer = 100 * asrp.wer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
+                cer = 100 * asrp.cer(targets, predicts, chunk_size=100) if len(target) > 0 else 100
                 result = {"WER": wer, "CER": cer}
                 data_score = sorted(data_score, key=lambda i: i[2]['wer'], reverse=False)
             if "nlg" in metric:
